# Awesome Panel Extensions

THIS PROJECT HAS JUST STARTED (20200721) AND IS RAPIDLY DEVELOPING

[Panel](https://panel.holoviz.org/) is a framework for creating **powerful, reactive analytics apps in Python using to tools you know and love**.

<a href="https://panel.holoviz.org/" target="_blank"><img src="https://panel.holoviz.org/_static/logo_stacked.png" style="display: block;margin-left: auto;margin-right: auto;height: 50px;"></a>

The `awesome-panel-extensions` package contains Panel Extensions and Tools that add to the power of Panel.

You can install the package via

```python
pip install awesome-panel-extensions
```

If you wan't to get started with an **example** check out the [Pandas Profile Report Reference Notebook](https://github.com/MarcSkovMadsen/awesome-panel-extensions/blob/master/examples/reference_gallery/panes/PandasProfileReport.ipynb)

[![Pandas Profile Report Reference Notebook](https://github.com/MarcSkovMadsen/awesome-panel-extensions/raw/master/assets/images/pandas-profile-report-pane-app.png)](https://github.com/MarcSkovMadsen/awesome-panel-extensions/blob/master/examples/reference_gallery/panes/PandasProfileReport.ipynb)

If you wan't to learn more checkout the [Package Documentation](https://awesome-panel.readthedocs.io/en/latest/packages/awesome-panel-extensions/index.html) to learn the why, what and how of the extension.

If you wan't to **develop your own Awesome Panel Extensions** check out the [Awesome Panel Extensions Guide](https://github.com/marcskovmadsen/awesome-panel-extensions).

Awesome Panel Extensions are provided by [awesome-panel.org](https://awesome-panel.org).

## LICENSE

The documentation is released under the [CC BY 4.0](https://creativecommons.org/licenses/by/4.0/) license.

The software, including the awesome-panel-extensions package, is released under the [GPLv3 license](https://www.gnu.org/licenses/gpl-3.0.html).

My understanding is that these licenses enables you to use and reuse the material freely as long as you give due credit in the form of a citation.

## For Contributers

### Package build

In the `setup.py` file update the version number and then run

```bash
python setup.py sdist bdist_wheel
```

### Package Deploy

To test

```bash
python -m twine upload --repository testpypi dist/*
```

to production

```bash
python -m twine upload dist/*
```